/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.zeppelin.integration;

import java.io.IOException;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;

public class FlinkIntegrationTest113 {

  @Nested
  @DisplayName("Scala 2.11")
  public class Scala211 extends FlinkIntegrationTest {

      @BeforeEach
      public void downloadFlink() throws IOException {
        download("1.13.2", "2.11");
      }
  }

  @Nested
  @DisplayName("Scala 2.12")
  public class Scala212 extends FlinkIntegrationTest {

      @BeforeEach
      public void downloadFlink() throws IOException {
        download("1.13.2", "2.12");
      }
  }
}
